package com.qunzhixinxi.hnqz.admin.api.dto;

import com.fasterxml.jackson.annotation.JsonProperty;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.Getter;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.util.Map;

/**
 * 自由职家的统一请求参数
 *
 * @author lixuesong
 * @date 2022年04月18日 12:00
 */
@Data
public class OladingCommonRequest implements Serializable {

	private static final long serialVersionUID = -467629451978460444L;

	/**
	 * 数据报文
	 */
	@NotNull(message = "req必填")
	private Req req;

	/**
	 * base64编码的签名数据
	 */
	@NotEmpty(message = "sign必填")
	private String sign;


	/**
	 * 数据报文
	 */
	@Data
	public static class Req implements Serializable {

		private static final long serialVersionUID = 2615670481019232417L;

		/**
		 * 接口名称
		 */
		private String name;

		/**
		 * 给客户端分配的唯一标识
		 */
		@JsonProperty("client_key")
		private String clientKey;

		/**
		 * 客户端生成报文的时间戳，如果和服务端时间相差过大，会被拒绝处理。
		 */
		private String timestamp;

		/**
		 * 接口业务数据
		 */
		private Map<String, Object> data;
	}

	/**
	 * 接口名称枚举
	 */
	@Getter
	@AllArgsConstructor
	public enum InterfaceName {

		// 接口名称
		SIGN_UP_NOTIFY("签约回调"), UPLOAD_ID_CARD_IMAGE("证照上传回调");

		/**
		 * 描述
		 */
		private String desc;
	}
}
