package com.qunzhixinxi.hnqz.admin.controller;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.bean.copier.CopyOptions;
import cn.hutool.json.JSONUtil;
import com.qunzhixinxi.hnqz.admin.api.dto.OladingCommonRequest;
import com.qunzhixinxi.hnqz.admin.entity.OladingInputRecord;
import com.qunzhixinxi.hnqz.admin.entity.model.GigOladingSignUpRequest;
import com.qunzhixinxi.hnqz.admin.service.gig.GigThirdApiService;
import com.qunzhixinxi.hnqz.admin.service.gig.OladingInputRecordService;
import com.qunzhixinxi.hnqz.admin.util.HMACSignProvider;
import com.qunzhixinxi.hnqz.common.core.exception.ValidateCodeException;
import com.qunzhixinxi.hnqz.common.core.util.R;
import com.qunzhixinxi.hnqz.common.log.annotation.SysLog;
import com.qunzhixinxi.hnqz.common.security.annotation.Inner;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.Map;

/**
 * 第三方零工接口
 *
 * @author lixuesong
 * @date 2022年04月17日 11:31
 */
@Slf4j
@RestController
@AllArgsConstructor
@RequestMapping("/gig-third-api")
public class GigThirdApiController {

	private final GigThirdApiService gigThirdApiService;

	private final OladingInputRecordService oladingInputRecordService;

	private static final HMACSignProvider hMACSignProvide = new HMACSignProvider();

	/**
	 * 公钥
	 */
	private static final String PUBLIC_KEY = "123123123";

	/**
	 * 算法类型
	 */
	private static final String ALGORITHM_TYPE = "HmacSHA256";

	/**
	 * 自由职家统一请求地址
	 *
	 * @return
	 */
	@Inner(value = false)
	@SysLog("自由职家统一请求地址")
	@PostMapping("/olading")
	public R<?> oladingRequest(@Valid @RequestBody OladingCommonRequest oladingRequest) {

		log.info("自由职家请求方法参数:" + JSONUtil.toJsonStr(oladingRequest));

		// 请求数据
		OladingCommonRequest.Req req = oladingRequest.getReq();
		// 签名数据
		String sign = oladingRequest.getSign();
		// 请求接口名称
		String interfaceName = req.getName();

		// 1.请求记录
		OladingInputRecord record = new OladingInputRecord();
		record.setInterfaceName(interfaceName);
		record.setReqBody(JSONUtil.toJsonStr(oladingRequest));
		record.setPrivateKey("");
		record.setPublicKey(PUBLIC_KEY);
		oladingInputRecordService.save(record);

		try {
			// 2. 验签
			boolean verfyResult =
					hMACSignProvide.verfy(ALGORITHM_TYPE, PUBLIC_KEY, JSONUtil.toJsonStr(req.getData()), sign);
			log.info("验签结果: {}", verfyResult);

			// 3.实际操作

			OladingCommonRequest.InterfaceName interfaceNameEnum = Enum.valueOf(OladingCommonRequest.InterfaceName.class, interfaceName);
			switch (interfaceNameEnum) {
				case SIGN_UP_NOTIFY:
					// 签约回调
					Map<String, Object> data = req.getData();
					GigOladingSignUpRequest signUpRequest =
							BeanUtil.mapToBean(data, GigOladingSignUpRequest.class, true, CopyOptions.create());
					gigThirdApiService.oladingSignUpNotify(signUpRequest);
					break;
				case UPLOAD_ID_CARD_IMAGE:
					// 证照上传回调 TODO
					break;
				default:

			}
			return R.ok();
		} catch (Exception e) {
			log.error("自由职家统一请求异常", e);
			if (e instanceof ValidateCodeException) {
				return R.failed(e.getMessage());
			}
			return R.failed("处理失败");
		}
	}

}
