package com.qunzhixinxi.hnqz.admin.service.gig.impl;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.qunzhixinxi.hnqz.admin.api.constant.CacheConstants;
import com.qunzhixinxi.hnqz.admin.entity.SysUserSub;
import com.qunzhixinxi.hnqz.admin.entity.dto.UserSignCertDTO;
import com.qunzhixinxi.hnqz.admin.entity.model.GigOladingSignUpRequest;
import com.qunzhixinxi.hnqz.admin.enums.GigTypeEnum;
import com.qunzhixinxi.hnqz.admin.enums.OladingCertStatus;
import com.qunzhixinxi.hnqz.admin.service.SysUserSubService;
import com.qunzhixinxi.hnqz.admin.service.gig.GigThirdApiService;
import com.qunzhixinxi.hnqz.admin.service.gig.SysUserSignCertService;
import com.qunzhixinxi.hnqz.common.core.exception.ValidateCodeException;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Collections;
import java.util.concurrent.TimeUnit;

/**
 * @author lixuesong
 * @date 2022年04月17日 11:55
 */
@Slf4j
@Service
@AllArgsConstructor
public class GigThirdApiServiceImpl implements GigThirdApiService {

	private final SysUserSubService sysUserSubService;

	private final SysUserSignCertService sysUserSignCertService;

	private final RedisTemplate redisTemplate;

	/**
	 * 自由职家签约结果回调
	 *
	 * @param signUpRequest
	 */
	@Override
	@Transactional(rollbackFor = Exception.class)
	public void oladingSignUpNotify(GigOladingSignUpRequest signUpRequest) {
		String requestId = signUpRequest.getRequestId();
		GigOladingSignUpRequest.CertStatus status = signUpRequest.getStatus();
		String redisKey = CacheConstants.OLADING_SIGN_UP_NOTIFY_KEY + requestId;
		Boolean absent = redisTemplate.opsForValue().setIfAbsent(redisKey, status.getCode(), 10, TimeUnit.SECONDS);
		if (!absent) {
			log.error("存在在途操作{}", requestId);
			throw new ValidateCodeException("存在在途操作");
		}
		try {
			// 先查询requestId是否存在
			SysUserSub userSub = sysUserSubService.getOne(Wrappers.<SysUserSub>lambdaQuery()
					.eq(SysUserSub::getGigType, GigTypeEnum.OLADING)
					.eq(SysUserSub::getRequestId, requestId));
			if (userSub == null) {
				throw new ValidateCodeException("requestId不存在");
			}
			if (OladingCertStatus.SIGNED.getCode().equals(String.valueOf(userSub.getCertStatus()))) {
				throw new ValidateCodeException("已回调");
			}
			// 更新状态
			SysUserSub updateUserSub = new SysUserSub();
			updateUserSub.setId(userSub.getId());
			updateUserSub.setCertStatus(status.getCode());
			sysUserSubService.updateById(userSub);

			// 如果成功，则发送证照上传MQ
			if (OladingCertStatus.SIGNED.getCode().equals(String.valueOf(status.getCode()))) {
				UserSignCertDTO userSignCertDTO = new UserSignCertDTO();
				userSignCertDTO.setUserId(userSub.getUserId());
				userSignCertDTO.setGigTypeList(Collections.singletonList(GigTypeEnum.OLADING));
				sysUserSignCertService.batchChannelCert(userSignCertDTO);
			}
		} finally {
			redisTemplate.delete(redisKey);
		}
	}
}
